@@ -9,6 +9,9 @@ class Act():
         self.actname = actname
         self.acthome = os.path.join(self.venue.VENUE_ROOT, 'acts', actname)
         self.uwsgifile = os.path.join(self.acthome, 'uwsgi.ini')
+        if not os.path.exists(self.acthome):
+            print 'Act %s does not exist in venue %s' % (self.venue.VENUE_NAME, self.actname)
+            raise
 
 
 def new_act(venue, actname):
@@ -29,7 +32,11 @@ def new_act(venue, actname):
     os.mkdir(acthome)
     act = Act(venue, actname)
     create_act_uwsgi_file(act)
-
+    if act:
+        s = 'created Backstage Act %s at %s' % (actname, acthome)
+        print s
+        s = 'using Act %s' % (act)
+        print s
     return act
 
 def create_act_uwsgi_file(act):
