@@ -11,6 +11,10 @@ class Venue():
     def __init__(self, venue_root):
         """Initialize a Backstage Venue instance. Required arguments are the name of the venue and the fullpath of the venue (name included)
         """
+        if not os.path.exists(venue_root):
+            print 'venue does not exist at %s' % (venue_root)
+            raise
+
         self.VENUE_ROOT = os.path.abspath(venue_root)
         self.VENUE_PATH,self.VENUE_DIRNAME = os.path.split(self.VENUE_ROOT)
         self.VENUE_NAME = self.VENUE_DIRNAME
